# Report Views
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/report-views#introduction)
  * [Default Report Views](https://help.sap.com/docs/leanix/ea/report-views#default-report-views)
  * [SAP LeanIX Technology Risk and Compliance - Report Views](https://help.sap.com/docs/leanix/ea/report-views#sap-leanix-technology-risk-and-compliance---report-views)
  * [Custom Views](https://help.sap.com/docs/leanix/ea/report-views#custom-views)


Get an overview of standard report views and learn how to use custom views.
